pub struct OwePublicKey {
pub group: u16,
pub key: Vec<u8>,
}Fields
group: u16key: Vec<u8>Trait Implementations
Sourceimpl Clone for OwePublicKey
impl Clone for OwePublicKey
Sourcefn clone(&self) -> OwePublicKey
fn clone(&self) -> OwePublicKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwePublicKey
impl Debug for OwePublicKey
Sourceimpl<___E> Encode<OwePublicKey<'static>, ___E> for OwePublicKeywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<OwePublicKey<'static>, ___E> for OwePublicKeywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OwePublicKey<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OwePublicKey<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<OwePublicKey<'static>, ___E> for &'a OwePublicKeywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<OwePublicKey<'static>, ___E> for &'a OwePublicKeywhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OwePublicKey<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OwePublicKey<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, OwePublicKey<'static>>, ___E> for OwePublicKey
impl<___E> EncodeOption<Box<'static, OwePublicKey<'static>>, ___E> for OwePublicKey
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OwePublicKey<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OwePublicKey<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OwePublicKey<'static>>, ___E> for &'a OwePublicKey
impl<'a, ___E> EncodeOption<Box<'static, OwePublicKey<'static>>, ___E> for &'a OwePublicKey
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OwePublicKey<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OwePublicKey<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for OwePublicKey
Sourceimpl<'de> FromWire<OwePublicKey<'de>> for OwePublicKey
impl<'de> FromWire<OwePublicKey<'de>> for OwePublicKey
Sourcefn from_wire(wire: OwePublicKey<'de>) -> Self
fn from_wire(wire: OwePublicKey<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OwePublicKey<'de>> for OwePublicKey
impl<'de> FromWireRef<OwePublicKey<'de>> for OwePublicKey
Sourcefn from_wire_ref(wire: &OwePublicKey<'de>) -> Self
fn from_wire_ref(wire: &OwePublicKey<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for OwePublicKey
impl Hash for OwePublicKey
Sourceimpl Ord for OwePublicKey
impl Ord for OwePublicKey
Sourcefn cmp(&self, other: &OwePublicKey) -> Ordering
fn cmp(&self, other: &OwePublicKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OwePublicKey
impl PartialEq for OwePublicKey
Sourcefn eq(&self, other: &OwePublicKey) -> bool
fn eq(&self, other: &OwePublicKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OwePublicKey
impl PartialOrd for OwePublicKey
impl StructuralPartialEq for OwePublicKey