#[repr(C)]pub struct WmmAcParams {
pub ecw_min: u8,
pub ecw_max: u8,
pub aifsn: u8,
pub txop_limit: Uint16,
pub acm: bool,
}Expand description
The wire type corresponding to WmmAcParams.
Fields
ecw_min: u8ecw_max: u8aifsn: u8txop_limit: Uint16acm: boolTrait Implementations
Sourceimpl Clone for WmmAcParams
impl Clone for WmmAcParams
Sourcefn clone(&self) -> WmmAcParams
fn clone(&self) -> WmmAcParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for WmmAcParams
impl Constrained for WmmAcParams
Sourceimpl Debug for WmmAcParams
impl Debug for WmmAcParams
Sourceimpl<___D> Decode<___D> for WmmAcParamswhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for WmmAcParamswhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<WmmAcParams, ___E> for WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WmmAcParams, ___E> for WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WmmAcParams>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WmmAcParams>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<WmmAcParams, ___E> for &'a WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WmmAcParams, ___E> for &'a WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WmmAcParams>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WmmAcParams>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4> Encode<WmmAcParams, ___E> for WmmAcParams<T0, T1, T2, T3, T4>
impl<___E, T0, T1, T2, T3, T4> Encode<WmmAcParams, ___E> for WmmAcParams<T0, T1, T2, T3, T4>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WmmAcParams>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WmmAcParams>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WmmAcParams> for WmmAcParams
impl FromWire<WmmAcParams> for WmmAcParams
Sourcefn from_wire(wire: WmmAcParams) -> Self
fn from_wire(wire: WmmAcParams) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<WmmAcParams> for WmmAcParams
impl FromWireRef<WmmAcParams> for WmmAcParams
Sourcefn from_wire_ref(wire: &WmmAcParams) -> Self
fn from_wire_ref(wire: &WmmAcParams) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for WmmAcParams
impl IntoNatural for WmmAcParams
Sourcetype Natural = WmmAcParams
type Natural = WmmAcParams
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WmmAcParams
impl Wire for WmmAcParams
Sourcetype Narrowed<'de> = WmmAcParams
type Narrowed<'de> = WmmAcParams
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.